LoggingInterceptor class

A simple logging interceptor for debugging.

Inheritance

Constructors

LoggingInterceptor({required void logger(String), String tag = 'WS'})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(dynamic error) Future
Called when a connection error occurs. Return null to suppress the error.
override
onReceive(WebSocketMessage message) Future<WebSocketMessage?>
Called after a message is received. Return null to drop the message.
override
onSend(WebSocketMessage message) Future<WebSocketMessage?>
Called before a message is sent. Return null to drop the message.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited