QueuedMessage class
A single message held in the queue with metadata for expiry tracking.
Constructors
- QueuedMessage({required WebSocketMessage message, required DateTime enqueuedAt, Duration? timeout})
Properties
- enqueuedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExpired → bool
-
no setter
- message → WebSocketMessage
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited