addInterceptor method
Adds an interceptor to the end of the chain.
Implementation
void addInterceptor(WebSocketInterceptor interceptor) {
_interceptors.add(interceptor);
}
Adds an interceptor to the end of the chain.
void addInterceptor(WebSocketInterceptor interceptor) {
_interceptors.add(interceptor);
}