InterceptorChain class

Manages an ordered chain of WebSocketInterceptors.

Constructors

InterceptorChain()

Properties

hashCode int
The hash code for this object.
no setterinherited
interceptors List<WebSocketInterceptor>
no setter
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(WebSocketInterceptor interceptor) → void
clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processError(dynamic error) Future
Runs error through each interceptor's onError. Returns null if suppressed.
processReceive(WebSocketMessage message) Future<WebSocketMessage?>
Runs message through each interceptor's onReceive. Returns null if suppressed.
processSend(WebSocketMessage message) Future<WebSocketMessage?>
Runs message through each interceptor's onSend. Returns null if suppressed.
remove(WebSocketInterceptor interceptor) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited